diff a/src/hotspot/share/interpreter/interpreterRuntime.hpp b/src/hotspot/share/interpreter/interpreterRuntime.hpp
--- a/src/hotspot/share/interpreter/interpreterRuntime.hpp
+++ b/src/hotspot/share/interpreter/interpreterRuntime.hpp
@@ -89,19 +89,43 @@
   static void    member_name_arg_or_null(JavaThread* current, address dmh, Method* m, address bcp);
 #endif
   static void    throw_pending_exception(JavaThread* current);
 
   static void resolve_from_cache(JavaThread* current, Bytecodes::Code bytecode);
+
+  // Used by ClassListParser.
+  static void resolve_get_put(Bytecodes::Code bytecode, int field_index,
+                              methodHandle& m, constantPoolHandle& pool, bool initialize_holder, TRAPS);
+  static void cds_resolve_invoke(Bytecodes::Code bytecode, int method_index,
+                                 methodHandle& m,
+                                 constantPoolHandle& pool, TRAPS);
+  static void cds_resolve_invokehandle(int raw_index,
+                                       constantPoolHandle& pool, TRAPS);
+  static void cds_resolve_invokedynamic(int raw_index,
+                                        constantPoolHandle& pool, TRAPS);
  private:
   // Statics & fields
+  static void resolve_getfield(JavaThread* current);
+  static void resolve_putfield(JavaThread* current);
+  static void resolve_getstatic(JavaThread* current);
+  static void resolve_putstatic(JavaThread* current);
+
   static void resolve_get_put(JavaThread* current, Bytecodes::Code bytecode);
 
   // Calls
+  static void resolve_invokevirtual(JavaThread* current);
+  static void resolve_invokespecial(JavaThread* current);
+  static void resolve_invokestatic(JavaThread* current);
+  static void resolve_invokeinterface(JavaThread* current);
+
   static void resolve_invoke(JavaThread* current, Bytecodes::Code bytecode);
   static void resolve_invokehandle (JavaThread* current);
   static void resolve_invokedynamic(JavaThread* current);
 
+  static void update_invoke_cp_cache_entry(CallInfo& info, Bytecodes::Code bytecode,
+                                           methodHandle& resolved_method,
+                                           constantPoolHandle& pool, int method_index);
  public:
   // Synchronization
   static void    monitorenter(JavaThread* current, BasicObjectLock* elem);
   static void    monitorenter_obj(JavaThread* current, oopDesc* obj);
   static void    monitorexit (BasicObjectLock* elem);
@@ -155,10 +179,13 @@
   static void    update_mdp_for_ret(JavaThread* current, int bci);
 #ifdef ASSERT
   static void    verify_mdp(Method* method, address bcp, address mdp);
 #endif // ASSERT
   static MethodCounters* build_method_counters(JavaThread* current, Method* m);
+
+  static void init_counters();
+  static void print_counters_on(outputStream* st);
 };
 
 
 class SignatureHandlerLibrary: public AllStatic {
  public:
